@@ -6,6 +6,7 @@ import scanpy as sc
 import anndata as ad
 import pandas as pd
 from torch.utils.tensorboard import SummaryWriter
+import matplotlib
 from matplotlib.figure import Figure
 import matplotlib.pyplot as plt
 from scipy.sparse.csr import spmatrix
@@ -86,8 +87,10 @@ def evaluate(adata: ad.AnnData,
 
     if not pd.api.types.is_categorical_dtype(adata.obs[cell_type_col]):
         _logger.warning("scETM.evaluate assumes discrete cell types. Converting cell_type_col to categorical.")
+        adata.obs[cell_type_col] = adata.obs[cell_type_col].astype(str).astype('category')
     if not pd.api.types.is_categorical_dtype(adata.obs[batch_col]):
         _logger.warning("scETM.evaluate assumes discrete batches. Converting batch_col to categorical.")
+        adata.obs[batch_col] = adata.obs[batch_col].astype(str).astype('category')
 
     # calculate neighbors
     _get_knn_indices(adata, use_rep=embedding_key, n_neighbors=n_neighbors, random_state=random_state, calc_knn=True)
@@ -465,3 +468,37 @@ def draw_embeddings(adata: ad.AnnData,
         return fig
     fig.clf()
     plt.close(fig)
+
+
+def set_figure_params(matplotlib_backend: str='agg',
+    dpi: int=120,
+    dpi_save: int=250,
+    frameon: bool = True,
+    vector_friendly: bool = True,
+    fontsize: int=10,
+    figsize: Sequence[int]=(10, 10)
+):
+    """Set figure parameters.
+    Args
+        backend: the backend to switch to.  This can either be one of th
+            standard backend names, which are case-insensitive:
+            - interactive backends:
+                GTK3Agg, GTK3Cairo, MacOSX, nbAgg,
+                Qt4Agg, Qt4Cairo, Qt5Agg, Qt5Cairo,
+                TkAgg, TkCairo, WebAgg, WX, WXAgg, WXCairo
+            - non-interactive backends:
+                agg, cairo, pdf, pgf, ps, svg, template
+            or a string of the form: ``module://my.module.name``.
+
+        dpi: resolution of rendered figures – this influences the size of
+            figures in notebooks.
+        dpi_save: resolution of saved figures. This should typically be higher
+            to achieve publication quality.
+        frameon: add frames and axes labels to scatter plots.
+        vector_friendly: plot scatter plots using `png` backend even when
+            exporting as `pdf` or `svg`.
+        fontsize: the fontsize for several `rcParams` entries.
+        figsize: plt.rcParams['figure.figsize'].
+    """
+    matplotlib.use(matplotlib_backend)
+    sc.set_figure_params(dpi=dpi, dpi_save=dpi_save, figsize=figsize, fontsize=fontsize, frameon=frameon, vector_friendly=vector_friendly)
